==> odoo12_addon_l10n_br_fiscal-12.0.3.4.0.99.dev4-py3-none-any.whl: odoo/addons/l10n_br_fiscal/report/account_invoice_report.py <==
# Copyright (C) 2016  Magno Costa - Akretion
# License AGPL-3 - See http://www.gnu.org/licenses/agpl-3.0.html

from openerp import fields, models
from openerp.addons import decimal_precision as dp

from ..models.l10n_br_account_product import PRODUCT_FISCAL_TYPE


class AccountInvoiceReport(models.Model):

    _inherit = "account.invoice.report"

    issuer = fields.Selection(
        selection=[("0", u"Emissão própria"), ("1", "Terceiros")],
        string="Emitente",
        readonly=True,
    )

    fiscal_type = fields.Selection(selection=PRODUCT_FISCAL_TYPE, string="Tipo Fiscal")

    cfop_id = fields.Many2one(
        comodel_name="l10n_br_account_product.cfop",
        domain="[('internal_type', '=', 'normal')]",
        string=u"CFOP",
        readonly=True,
    )

    icms_value = fields.Float(
        string=u"Valor ICMS", required=True, digits=dp.get_precision("Account")
    )

    icms_st_value = fields.Float(
        string=u"Valor ICMS ST", required=True, digits=dp.get_precision("Account")
    )

    ipi_value = fields.Float(
        string=u"Valor IPI", required=True, digits=dp.get_precision("Account")
    )

    pis_value = fields.Float(
        string=u"Valor PIS", required=True, digits=dp.get_precision("Account")
    )

    cofins_value = fields.Float(
        string=u"Valor COFINS", required=True, digits=dp.get_precision("Account")
    )

    ii_value = fields.Float(
        string=u"Valor II", required=True, digits=dp.get_precision("Account")
    )

    total_with_taxes = fields.Float(
        string=u"Total com Impostos", required=True, digits=dp.get_precision("Account")
    )

    def _select(self):
        return super(AccountInvoiceReport, self)._select() + (
            ", sub.issuer as issuer"
            ", sub.fiscal_type as fiscal_type"
            ", sub.cfop_id as cfop_id"
            ", sub.icms_value as icms_value"
            ", sub.icms_st_value as icms_st_value"
            ", sub.ipi_value as ipi_value"
            ", sub.pis_value as pis_value"
            ", sub.cofins_value as cofins_value"
            ", sub.ii_value as ii_value"
            ", sub.total_with_taxes as total_with_taxes"
        )

    def _sub_select(self):
        return super(AccountInvoiceReport, self)._sub_select() + (
            ", ai.issuer "
            ", ai.fiscal_type "
            ", ail.cfop_id as cfop_id"
            ", SUM(ail.icms_value) as icms_value"
            ", SUM(ail.icms_st_value) as icms_st_value"
            ", SUM(ail.ipi_value) as ipi_value"
            ", SUM(ail.pis_value) as pis_value"
            ", SUM(ail.cofins_value) as cofins_value"
            ", SUM(ail.ii_value) as ii_value"
            ", SUM("
            "ail.price_subtotal + ail.ipi_value + "
            "ail.icms_st_value + ail.freight_value + "
            "ail.insurance_value + ail.other_costs_value) "
            "as total_with_taxes"
        )

    def _group_by(self):
        return super(AccountInvoiceReport, self)._group_by() + (
            ", ai.issuer" ", ai.fiscal_type" ", ail.cfop_id"
        )

==> odoo12_addon_l10n_br_fiscal-12.0.11.3.0-py3-none-any.whl: odoo/addons/l10n_br_fiscal/report/account_invoice_report.py <==
# Copyright (C) 2016  Magno Costa - Akretion
# License AGPL-3 - See http://www.gnu.org/licenses/agpl-3.0.html

from openerp import fields, models
from openerp.addons import decimal_precision as dp

from ..models.l10n_br_account_product import PRODUCT_FISCAL_TYPE


class AccountInvoiceReport(models.Model):

    _inherit = "account.invoice.report"

    issuer = fields.Selection(
        selection=[("0", u"Emissão própria"), ("1", "Terceiros")],
        string="Emitente",
        readonly=True,
    )

    fiscal_type = fields.Selection(selection=PRODUCT_FISCAL_TYPE, string="Tipo Fiscal")

    cfop_id = fields.Many2one(
        comodel_name="l10n_br_account_product.cfop",
        domain="[('internal_type', '=', 'normal')]",
        string=u"CFOP",
        readonly=True,
    )

    icms_value = fields.Float(
        string=u"Valor ICMS", required=True, digits=dp.get_precision("Account")
    )

    icms_st_value = fields.Float(
        string=u"Valor ICMS ST", required=True, digits=dp.get_precision("Account")
    )

    ipi_value = fields.Float(
        string=u"Valor IPI", required=True, digits=dp.get_precision("Account")
    )

    pis_value = fields.Float(
        string=u"Valor PIS", required=True, digits=dp.get_precision("Account")
    )

    cofins_value = fields.Float(
        string=u"Valor COFINS", required=True, digits=dp.get_precision("Account")
    )

    ii_value = fields.Float(
        string=u"Valor II", required=True, digits=dp.get_precision("Account")
    )

    total_with_taxes = fields.Float(
        string=u"Total com Impostos", required=True, digits=dp.get_precision("Account")
    )

    def _select(self):
        return super(AccountInvoiceReport, self)._select() + (
            ", sub.issuer as issuer"
            ", sub.fiscal_type as fiscal_type"
            ", sub.cfop_id as cfop_id"
            ", sub.icms_value as icms_value"
            ", sub.icms_st_value as icms_st_value"
            ", sub.ipi_value as ipi_value"
            ", sub.pis_value as pis_value"
            ", sub.cofins_value as cofins_value"
            ", sub.ii_value as ii_value"
            ", sub.total_with_taxes as total_with_taxes"
        )

    def _sub_select(self):
        return super(AccountInvoiceReport, self)._sub_select() + (
            ", ai.issuer "
            ", ai.fiscal_type "
            ", ail.cfop_id as cfop_id"
            ", SUM(ail.icms_value) as icms_value"
            ", SUM(ail.icms_st_value) as icms_st_value"
            ", SUM(ail.ipi_value) as ipi_value"
            ", SUM(ail.pis_value) as pis_value"
            ", SUM(ail.cofins_value) as cofins_value"
            ", SUM(ail.ii_value) as ii_value"
            ", SUM("
            "ail.price_subtotal + ail.ipi_value + "
            "ail.icms_st_value + ail.freight_value + "
            "ail.insurance_value + ail.other_value) "
            "as total_with_taxes"
        )

    def _group_by(self):
        return super(AccountInvoiceReport, self)._group_by() + (
            ", ai.issuer" ", ai.fiscal_type" ", ail.cfop_id"
        )
